Rename variable with confusing name

Message ID 53E287C8.6080207@ericsson.com
State Committed
Headers

Commit Message

Simon Marchi Aug. 6, 2014, 7:53 p.m. UTC
  On 14-08-06 03:51 PM, Joel Brobecker wrote:
>> Pushed with modifications to scan_dyntag_auxv as well.
> 
> Thanks! Just to follow our procedures when a patch being pushed
> is different from the patch already posted, would you mind posting
> the patch you pushed here?

Oh sure, I tend to forget things like that. Good thing you remind me.

(I hope Thunderbird doesn't mess up with line wrapping.)

From b6d7a4bf2932e5ae173dd7fb0213c3b004da8462 Mon Sep 17 00:00:00 2001
From: Simon Marchi <simon.marchi@ericsson.com>
Date: Fri, 1 Aug 2014 18:09:06 -0400
Subject: [PATCH] Rename variable with confusing name

I saw this gem of not so legible code in solib-svr4.c (scan_dyntag):

	if (dyn_tag == dyntag)

and thought it deserved a small rename.

This just renames variables to be a bit more clear for those who read the
code. I also constified the parameter because, why not. The same was
done in scan_dyntag_auxv as well.

Tested only by rebuilding, since the change was done mechanically.

gdb/Changelog:

2014-08-01  Simon Marchi  <simon.marchi@ericsson.com>

	* solib-svr4.c (scan_dyntag): Rename dyntag and dyn_tag variables.
	(scan_dyntag_auxv): Same.
---
 gdb/ChangeLog    |  5 +++++
 gdb/solib-svr4.c | 34 +++++++++++++++++-----------------
 2 files changed, 22 insertions(+), 17 deletions(-)
  

Patch

diff --git a/gdb/ChangeLog b/gdb/ChangeLog
index 7ce30c8..c667f3e 100644
--- a/gdb/ChangeLog
+++ b/gdb/ChangeLog
@@ -1,3 +1,8 @@ 
+2014-08-06  Simon Marchi  <simon.marchi@ericsson.com>
+
+	* solib-svr4.c (scan_dyntag): Rename dyntag and dyn_tag variables.
+	(scan_dyntag_auxv): Same.
+
 2014-08-06  Yao Qi  <yao@codesourcery.com>

 	* amd64-linux-nat.c: Remove duplicated include
diff --git a/gdb/solib-svr4.c b/gdb/solib-svr4.c
index af9d648..05f29a9 100644
--- a/gdb/solib-svr4.c
+++ b/gdb/solib-svr4.c
@@ -614,14 +614,14 @@  find_program_interpreter (void)
 }


-/* Scan for DYNTAG in .dynamic section of ABFD.  If DYNTAG is found 1 is
-   returned and the corresponding PTR is set.  */
+/* Scan for DESIRED_DYNTAG in .dynamic section of ABFD.  If DESIRED_DYNTAG is
+   found, 1 is returned and the corresponding PTR is set.  */

 static int
-scan_dyntag (int dyntag, bfd *abfd, CORE_ADDR *ptr)
+scan_dyntag (const int desired_dyntag, bfd *abfd, CORE_ADDR *ptr)
 {
   int arch_size, step, sect_size;
-  long dyn_tag;
+  long current_dyntag;
   CORE_ADDR dyn_ptr, dyn_addr;
   gdb_byte *bufend, *bufstart, *buf;
   Elf32_External_Dyn *x_dynp_32;
@@ -679,18 +679,18 @@  scan_dyntag (int dyntag, bfd *abfd, CORE_ADDR *ptr)
     if (arch_size == 32)
       {
 	x_dynp_32 = (Elf32_External_Dyn *) buf;
-	dyn_tag = bfd_h_get_32 (abfd, (bfd_byte *) x_dynp_32->d_tag);
+	current_dyntag = bfd_h_get_32 (abfd, (bfd_byte *) x_dynp_32->d_tag);
 	dyn_ptr = bfd_h_get_32 (abfd, (bfd_byte *) x_dynp_32->d_un.d_ptr);
       }
     else
       {
 	x_dynp_64 = (Elf64_External_Dyn *) buf;
-	dyn_tag = bfd_h_get_64 (abfd, (bfd_byte *) x_dynp_64->d_tag);
+	current_dyntag = bfd_h_get_64 (abfd, (bfd_byte *) x_dynp_64->d_tag);
 	dyn_ptr = bfd_h_get_64 (abfd, (bfd_byte *) x_dynp_64->d_un.d_ptr);
       }
-     if (dyn_tag == DT_NULL)
+     if (current_dyntag == DT_NULL)
        return 0;
-     if (dyn_tag == dyntag)
+     if (current_dyntag == desired_dyntag)
        {
 	 /* If requested, try to read the runtime value of this .dynamic
 	    entry.  */
@@ -713,16 +713,16 @@  scan_dyntag (int dyntag, bfd *abfd, CORE_ADDR *ptr)
   return 0;
 }

-/* Scan for DYNTAG in .dynamic section of the target's main executable,
-   found by consulting the OS auxillary vector.  If DYNTAG is found 1 is
-   returned and the corresponding PTR is set.  */
+/* Scan for DESIRED_DYNTAG in .dynamic section of the target's main executable,
+   found by consulting the OS auxillary vector.  If DESIRED_DYNTAG is found, 1
+   is returned and the corresponding PTR is set.  */

 static int
-scan_dyntag_auxv (int dyntag, CORE_ADDR *ptr)
+scan_dyntag_auxv (const int desired_dyntag, CORE_ADDR *ptr)
 {
   enum bfd_endian byte_order = gdbarch_byte_order (target_gdbarch ());
   int sect_size, arch_size, step;
-  long dyn_tag;
+  long current_dyntag;
   CORE_ADDR dyn_ptr;
   gdb_byte *bufend, *bufstart, *buf;

@@ -742,7 +742,7 @@  scan_dyntag_auxv (int dyntag, CORE_ADDR *ptr)
       {
 	Elf32_External_Dyn *dynp = (Elf32_External_Dyn *) buf;

-	dyn_tag = extract_unsigned_integer ((gdb_byte *) dynp->d_tag,
+	current_dyntag = extract_unsigned_integer ((gdb_byte *) dynp->d_tag,
 					    4, byte_order);
 	dyn_ptr = extract_unsigned_integer ((gdb_byte *) dynp->d_un.d_ptr,
 					    4, byte_order);
@@ -751,15 +751,15 @@  scan_dyntag_auxv (int dyntag, CORE_ADDR *ptr)
       {
 	Elf64_External_Dyn *dynp = (Elf64_External_Dyn *) buf;

-	dyn_tag = extract_unsigned_integer ((gdb_byte *) dynp->d_tag,
+	current_dyntag = extract_unsigned_integer ((gdb_byte *) dynp->d_tag,
 					    8, byte_order);
 	dyn_ptr = extract_unsigned_integer ((gdb_byte *) dynp->d_un.d_ptr,
 					    8, byte_order);
       }
-    if (dyn_tag == DT_NULL)
+    if (current_dyntag == DT_NULL)
       break;

-    if (dyn_tag == dyntag)
+    if (current_dyntag == desired_dyntag)
       {
 	if (ptr)
 	  *ptr = dyn_ptr;